@@ -31,24 +31,22 @@ c   leng: real*8. input.  length along cosz direction.
 c   function value.      thickness of air in kg/m2.
 c
       implicit none
+#include  "Ztrack.h"
 #include  "Ztrackp.h"
+#include  "Ztrackv.h"
 #include  "Zatmos.h"
 
       real*8 z, cosz, leng, clen2thickEx, clen2thickAp
       real*8  clen2thickTA
 
-
-      if(ExactThick) then
+      if(UseTbl .and. z .lt. Htop) then
+         clen2thick = clen2thickTA(z, leng)
+      elseif(ExactThick) then
          clen2thick = clen2thickEx(z, cosz, leng, 10)
       elseif(abs(cosz) .gt. 0.5) then
          clen2thick = clen2thickAp(z, cosz, leng)
       else
-         if(OneDim .eq. 1 .and. z .lt. Htop) then
-c             if one dimensional, use table method.
-            clen2thick= clen2thickTA(z, leng)
-         else
-            clen2thick = clen2thickEx(z, cosz, leng, 10)
-         endif
+         clen2thick = clen2thickEx(z, cosz, leng, 10)
       endif
       end
 c     cLen2thickAp
