@@ -55,6 +55,10 @@ c                                     (in 'xyz')
 	record /magfield/ Mag
 	integer MaxPtcl
 
+        logical FromEpics     !  to control muon iteraction (pair,brem,nuci)
+                              !  must be made t, when Epics treats muon.
+                              !  if Cosmos uses Epics, this must be made to
+                              !  be t/f depending on Epics mode, or Cosmos mode
 	parameter (
 #ifdef MAX_PTCL
      *     MaxPtcl = MAX_PTCL
@@ -74,7 +78,9 @@ c
      *  KEmin2, KEminCas2, Ethin, Upsilon, Xai, 
      *  ObserveAS, Nproduced, 
      *  MoveStat,  NumberOfInte, ProcessNo, 
-     *  TargetNucleonNo, TargetProtonNo, Upgoing, UseTbl
+     *  TargetNucleonNo, TargetProtonNo, Upgoing, UseTbl,
+     *  FromEpics 
+
 
 
 
