@@ -26,9 +26,14 @@ c                reset the seed.
          else
 c              save the initial seed of random number
             call rnd1s(SeedSave)
-            if(Job .eq. 'skeleton') then
-               call cwriteSeed
-            elseif(Job .ne. 'flesh' .and. SeedFile .ne. ' ') then
+c            if(Job .eq. 'skeleton') then
+c               call cwriteSeed
+c            elseif(Job .ne. 'flesh' .and. SeedFile .ne. ' ') then
+c               call cwriteSeed
+c            endif
+c             take record  of seed, if non flesh, non skeleton
+c             job and SeedFile is given.
+            if(Job .eq. ' ' .and. SeedFile .ne. ' ') then
                call cwriteSeed
             endif
          endif            
@@ -73,7 +78,28 @@ c          read iformation for initial random number at flesh time
 
       integer ir(2), no
 
-      read(SeedFileDev, *) ir, no
+      integer nn
+      integer count
+      data count/0/
+      save count
+
+      do while(.true.)
+         read(SeedFileDev, *, end=100) ir, nn
+         if(nn .ge. EventNo) goto 200  ! skip already processed ones
+      enddo
+ 100  continue
+      if(count .eq. 0) then
+         count = count + 1
+         call cerrorMsg(
+     *        'No more events to be fleshed',1)
+         call cerrorMsg(
+     *        'EOF of the seed file reached', 1)
+      else
+         call cerrorMsg(
+     *  '2nd time to read EOF of the  seed file',0)
+      endif
+ 200  continue
+      no = nn
       end
 c      inquire the event number
       subroutine cqEventNo(num, cumnum)
