@@ -9,8 +9,10 @@ c               copy of it is saved as 'IncidentCopy', and can be
 c               inquired by call cqIncident(...)
 c
 #include  "Ztrack.h"
+#include  "Ztrackv.h"
 #include  "Zmanagerp.h"
 
+
       record /track/ incident
       record /coord/ angle
 
@@ -103,8 +105,13 @@ c         than the detector, make it non zero.
      *  ObsSites(NoOfSites).pos.radiallen + OffsetHeight, 
      *  Eradius + HeightOfInj,  zenithcos )  ! we need zenith angle here
 
-      if(Reverse .eq. 0 .and. zenithcos .lt. 0.
-     *  .or. Reverse .ne. 0 .and. zenithcos .gt. 0.) then
+c         primary is going upward even if Reverse = 0.
+      Upgoing = Reverse .eq. 0 .and. zenithcos .lt. 0. 
+     *   .and. HeightOfInj .lt. ObsSites(NoOfSites).pos.height
+
+      if(( Reverse .eq. 0 .and. zenithcos .lt. 0. 
+     *  .and.  HeightOfInj .gt. ObsSites(NoOfSites).pos.height)
+     *  .or. ( Reverse .ne. 0 .and. zenithcos .gt. 0.)) then
 c            distance to the conjugate point
          to100km = to100km -
      *    2*(ObsSites(NoOfSites).pos.radiallen + OffsetHeight)*
@@ -117,7 +124,7 @@ c           injection point
          incident.pos.xyz.r(i) = ObsSites(NoOfSites).pos.xyz.r(i) 
      *    + Offset.r(i)  + to100km * DcAtObsXyz.r(i)
       enddo
-c
+
       call csetPos(incident.pos)
       call csetDirCos(DcAtObsXyz, incident)   ! set dc and coszenith in incident
 c           momentum business
@@ -126,35 +133,47 @@ c           momentum business
 c          set time 0
       incident.t = 0.
       incident.wgt = 1.       ! weight is 1.
-      incident.where = 1      !  Next obs site
+
+c           Next obs site
+      if( Upgoing ) then
+         incident.where = NoOfSites
+      else
+         incident.where = 1     
+      endif
+
       incident.asflag = 0
       incident.pos.colheight = Infty  ! latest nuc. collision height
       IncidentCopy = incident
 
 c           shift the origin of detectors to be on the primary track
-c           if OffsetHight=0 and down going primary.
-      if(OffsetHeight .eq. 0. .and. zenithcos .ge. 0.) then
-         do i = 1, NoOfSites-1
-            len = clenbetween2h(
-     *      ObsSites(NoOfSites).pos.radiallen, 
-     *      ObsSites(i).pos.radiallen,
-     *      zenithcos ) 
-            do j = 1, 3
-               ObsSites(i).pos.xyz.r(j) = 
-     *         ObsSites(NoOfSites).pos.xyz.r(j) + len * DcAtObsXyz.r(j)
+c           if OffsetHight=0
+      if(OffsetHeight .eq. 0.) then
+         if(zenithcos .ge. 0. .or. Upgoing) then
+            do i = 1, NoOfSites-1
+               len = clenbetween2h(
+     *              ObsSites(NoOfSites).pos.radiallen, 
+     *              ObsSites(i).pos.radiallen,
+     *              zenithcos ) 
+
+               do j = 1, 3
+                  ObsSites(i).pos.xyz.r(j) = 
+     *            ObsSites(NoOfSites).pos.xyz.r(j)
+     *             + len * DcAtObsXyz.r(j)
+
+               enddo
             enddo
-         enddo
-         do i = 1, NoOfASSites-1
-            len = clenbetween2h(
-     *      ASObsSites(NoOfASSites).pos.radiallen, 
-     *      ASObsSites(i).pos.radiallen,
-     *      zenithcos ) 
-            do j =1 , 3
-               ASObsSites(i).pos.xyz.r(j) = 
+            do i = 1, NoOfASSites-1
+               len = clenbetween2h(
+     *         ASObsSites(NoOfASSites).pos.radiallen, 
+     *         ASObsSites(i).pos.radiallen,
+     *         zenithcos ) 
+               do j =1 , 3
+                  ASObsSites(i).pos.xyz.r(j) = 
      *                ASObsSites(NoOfSites).pos.xyz.r(j)
      *                + len * DcAtObsXyz.r(j)
+               enddo
             enddo
-         enddo
+         endif
       endif
 c          compute min time from  the injection point to each
 c         obs level.
