@@ -14,7 +14,11 @@ c  the resultant data can be drawn by, say, gnuplot.
          record /magfield/ b, hva
          integer icon, ilat, ilong
 c
-         year=1995.
+         year=2000.
+         call cerrorMsg(
+     *   'Enter year of geomagnetism (=2000)', 1)
+         read(*,*) year
+
          h  = 0.d0
          write(*,'("#     lat   long   H   V (Tesla) Ang(deg) ")')
          do ilat = -90, 90,  5
@@ -23,8 +27,6 @@ c
                long = ilong
                call csetCoord('llh', lat, long, h, llh)
                call cgeomag(year, llh, b, icon)
-cc             write(*,*) ' icon=',icon
-c              write(*,*) ' ned=', b.n, b.e, b.d
                call cned2hva(b, hva)
 c              call ctransMagTo('xyz', llh, b, b)
 c              write(*,*) ' x=',b.x, ' y=', b.y, ' z=', b.z
@@ -37,5 +39,6 @@ c              write(*,*) ' x=',b.x, ' y=', b.y, ' z=', b.z
 cc             call cprintMagF(b)
 cc             call cprintMagF(hva)
             enddo
+            write(*,*)
          enddo   
          end
